@@ -28,41 +28,25 @@
 
 G_BEGIN_DECLS
 
+/* UUIDs for log messages */
+#define GSM_MANAGER_STARTUP_SUCCEEDED_MSGID     "0ce153587afa4095832d233c17a88001"
+#define GSM_MANAGER_UNRECOVERABLE_FAILURE_MSGID "10dd2dc188b54a5e98970f56499d1f73"
+
 #define GSM_TYPE_MANAGER         (gsm_manager_get_type ())
-G_DECLARE_DERIVABLE_TYPE (GsmManager, gsm_manager, GSM, MANAGER, GObject)
-
-struct _GsmManagerClass
-{
-        GObjectClass   parent_class;
-
-        void          (* phase_changed)       (GsmManager      *manager,
-                                               const char      *phase);
-};
+G_DECLARE_FINAL_TYPE (GsmManager, gsm_manager, GSM, MANAGER, GObject)
 
 typedef enum {
-        /* gsm's own startup/initialization phase */
-        GSM_MANAGER_PHASE_STARTUP = 0,
-        /* gnome-initial-setup */
-        GSM_MANAGER_PHASE_EARLY_INITIALIZATION,
-        /* gnome-keyring-daemon */
-        GSM_MANAGER_PHASE_PRE_DISPLAY_SERVER,
-        /* wayland compositor and XWayland */
-        GSM_MANAGER_PHASE_DISPLAY_SERVER,
-        /* xrandr setup, gnome-settings-daemon, etc */
-        GSM_MANAGER_PHASE_INITIALIZATION,
-        /* window/compositing managers */
-        GSM_MANAGER_PHASE_WINDOW_MANAGER,
-        /* apps that will create _NET_WM_WINDOW_TYPE_PANEL windows */
-        GSM_MANAGER_PHASE_PANEL,
-        /* apps that will create _NET_WM_WINDOW_TYPE_DESKTOP windows */
-        GSM_MANAGER_PHASE_DESKTOP,
-        /* everything else */
+        /* We're waiting for systemd to start session services, the compositor, etc */
+        GSM_MANAGER_PHASE_INITIALIZATION = 0,
+        /* The session is running, but we're still launching the user's autostart apps */
         GSM_MANAGER_PHASE_APPLICATION,
-        /* done launching */
+        /* The session is running */
         GSM_MANAGER_PHASE_RUNNING,
-        /* shutting down */
+        /* Someone requested for the session to end,  */
         GSM_MANAGER_PHASE_QUERY_END_SESSION,
+        /* The session is shutting down */
         GSM_MANAGER_PHASE_END_SESSION,
+        /* The session has shut down, and gnome-session is about to exit */
         GSM_MANAGER_PHASE_EXIT
 } GsmManagerPhase;
 
@@ -81,20 +65,13 @@ typedef enum
 #define GSM_MANAGER_ERROR gsm_manager_error_quark ()
 GQuark              gsm_manager_error_quark                    (void);
 
-GsmManager *        gsm_manager_new                            (GsmStore       *client_store,
-                                                                gboolean        failsafe,
-                                                                gboolean        systemd_managed);
+GsmManager *        gsm_manager_new                            (void);
 GsmManager *        gsm_manager_get                            (void);
 
-
-gboolean            gsm_manager_get_failsafe                   (GsmManager     *manager);
 gboolean            gsm_manager_get_dbus_disconnected          (GsmManager *manager);
-gboolean            gsm_manager_get_systemd_managed            (GsmManager     *manager);
 
 gboolean            gsm_manager_add_autostart_app              (GsmManager     *manager,
                                                                 const char     *path);
-gboolean            gsm_manager_add_required_app               (GsmManager     *manager,
-                                                                const char     *path);
 gboolean            gsm_manager_add_autostart_apps_from_dir    (GsmManager     *manager,
                                                                 const char     *path);
 gboolean            gsm_manager_add_legacy_session_apps        (GsmManager     *manager,
@@ -102,14 +79,8 @@ gboolean            gsm_manager_add_legacy_session_apps        (GsmManager     *
 
 void                gsm_manager_start                          (GsmManager     *manager);
 
-char *              _gsm_manager_get_default_session           (GsmManager     *manager);
-
 void                _gsm_manager_set_active_session            (GsmManager     *manager,
-                                                                const char     *session_name,
-                                                                gboolean        is_fallback);
-
-void                _gsm_manager_set_renderer                  (GsmManager     *manager,
-                                                                const char     *renderer);
+                                                                const char     *session_name);
 
 gboolean            gsm_manager_logout                         (GsmManager     *manager,
                                                                 guint           logout_mode,
@@ -118,6 +89,8 @@ gboolean            gsm_manager_logout                         (GsmManager     *
 gboolean            gsm_manager_set_phase                      (GsmManager     *manager,
                                                                 GsmManagerPhase phase);
 
+void                gsm_quit                                   (void);
+
 G_END_DECLS
 
 #endif /* __GSM_MANAGER_H */
